{*******************************************************}
{                                                       }
{                      RSControls                       }
{                                                       }
{        Copyright (c) 2000, 2001 by RealSoft           }
{	 	    E-mail & http:			}
{          dclrs@realsoft2000.virtualave.net            }
{*******************************************************}
unit RSControls;

interface

{$R *.dcr}
uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls;

type

  { TRSPanel }
  TRSPanel = class(TCustomPanel)
  private
    FWallpaper: TPicture;
    procedure SetWallpaper(Value: TPicture);
    procedure WallpaperChanged(Sender: TObject);
  protected
    procedure Paint; override;
  public
    property DockManager;
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property Align;
    property Alignment;
    property Anchors;
    property AutoSize;
    property BevelInner;
    property BevelOuter;
    property BevelWidth;
    property BiDiMode;
    property BorderWidth;
    property BorderStyle;
    property Caption;
    property Color;
    property Constraints;
    property Ctl3D;
    property UseDockManager default True;
    property DockSite;
    property DragCursor;
    property DragKind;
    property DragMode;
    property Enabled;
    property FullRepaint;
    property Font;
    property Locked;
    property ParentBiDiMode;
    property ParentColor;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property TabOrder;
    property TabStop;
    property Visible;
    property OnCanResize;
    property OnClick;
    property OnConstrainedResize;
    property OnDockDrop;
    property OnDockOver;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDock;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnGetSiteInfo;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnResize;
    property OnStartDock;
    property OnStartDrag;
    property OnUnDock;
    property Wallpaper: TPicture read FWallpaper write SetWallpaper;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('RS Control', [TRSPanel]);
end;

////////////////////////////////////////////////////  { TRSPanel }
constructor TRSPanel.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FWallpaper := TPicture.Create;
  FWallpaper.OnChange := WallpaperChanged;
end;

destructor TRSPanel.Destroy;
begin
  FWallpaper.OnChange := nil;
  FWallpaper.Free;
  FWallpaper := nil;
  inherited Destroy;
end;

procedure TRSPanel.WallpaperChanged(Sender: TObject);
begin
  Invalidate;
end;

procedure TRSPanel.SetWallpaper(Value: TPicture);
begin
  FWallpaper.Assign(Value);
end;

procedure TRSPanel.Paint;
var
  XCnt, YCnt, X, Y: Integer;
  BevelSize, SaveIndex: Integer;
  Rect: TRect;
begin
    Rect := ClientRect;
    BevelSize := BorderWidth;
    if BevelOuter <> bvNone then Inc(BevelSize, BevelWidth);
    if BevelInner <> bvNone then Inc(BevelSize, BevelWidth);
    InflateRect(Rect, -BevelSize, -BevelSize);
    inherited Paint;
    if (FWallpaper.Graphic <> nil) and (FWallpaper.Width > 0) and
      (FWallpaper.Height > 0) then
    begin
      SaveIndex := SaveDC(Canvas.Handle);
      try
        with Rect do
          IntersectClipRect(Canvas.Handle, Left, Top, Right - Left +
            BevelSize, Bottom - Top + BevelSize);
          XCnt := (ClientWidth - 2 * BevelSize) div FWallpaper.Width;
          YCnt := (ClientHeight - 2 * BevelSize) div FWallpaper.Height;
          for X := 0 to XCnt do
            for Y := 0 to YCnt do
              Canvas.Draw(Rect.Left + X * FWallpaper.Width,
                Rect.Top + Y * FWallpaper.Height, FWallpaper.Graphic);
      finally
        RestoreDC(Canvas.Handle, SaveIndex);
      end;
    end;
end;


end.
